Contributing to LXDock
######################

Thank you for contributing to LXDock! A list of simple rules is available on the online
documentation to help you contribute to this project: https://lxdock.readthedocs.io/en/stable/contributing.html
